@@ -4,7 +4,7 @@
   Distortion Magic Tool Plugin
   Tux Paint - A simple drawing program for children.
 
-  Copyright (c) 2002-2008 by Bill Kendrick and others; see AUTHORS.txt
+  Copyright (c) 2002-2021 by Bill Kendrick and others; see AUTHORS.txt
   bill@newbreedsoftware.com
   http://www.tuxpaint.org/
 
@@ -23,7 +23,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
-  Last updated: July 8, 2008
+  Last updated: September 21, 2021
   $Id$
 */
 
@@ -59,6 +59,7 @@ int distortion_init(magic_api * api);
 int distortion_get_tool_count(magic_api * api);
 SDL_Surface *distortion_get_icon(magic_api * api, int which);
 char *distortion_get_name(magic_api * api, int which);
+int distortion_get_group(magic_api * api, int which);
 char *distortion_get_description(magic_api * api, int which, int mode);
 int distortion_requires_colors(magic_api * api, int which);
 void distortion_shutdown(magic_api * api);
@@ -135,6 +136,14 @@ char *distortion_get_name(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_
 }
 
 
+// Report our "Magic" tool groups
+
+int distortion_get_group(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
+{
+  return MAGIC_TYPE_DISTORTS;
+}
+
+
 // Report our "Magic" tool descriptions
 
 char *distortion_get_description(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED,
