@@ -1,7 +1,7 @@
 /*
  * Folds the picture down from the corners.
  *
- * Last updated: 2019-08-29
+ * Last updated: 2021-09-20
  */
 
 //optimized version soon :)
@@ -43,6 +43,7 @@ int fold_init(magic_api * api);
 int fold_get_tool_count(magic_api * api);
 SDL_Surface *fold_get_icon(magic_api * api, int which);
 char *fold_get_name(magic_api * api, int which);
+int fold_get_group(magic_api * api, int which);
 char *fold_get_description(magic_api * api, int which, int mode);
 int fold_requires_colors(magic_api * api, int which);
 void fold_release(magic_api * api, int which,
@@ -103,6 +104,11 @@ char *fold_get_name(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED
   return (gettext_noop("Fold"));
 }
 
+int fold_get_group(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
+{
+  return MAGIC_TYPE_PICTURE_WARPS;
+}
+
 char *fold_get_description(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED)
 {
   return strdup(gettext_noop("Choose a background color and click to turn the corner of the page over."));
