@@ -4,7 +4,7 @@
   Glass Tile Magic Tool Plugin
   Tux Paint - A simple drawing program for children.
 
-  Copyright (c) 2002-2008 by Bill Kendrick and others; see AUTHORS.txt
+  Copyright (c) 2002-2021 by Bill Kendrick and others; see AUTHORS.txt
   bill@newbreedsoftware.com
   http://www.tuxpaint.org/
 
@@ -23,7 +23,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
-  Last updated: July 9, 2008
+  Last updated: November 8, 2021
   $Id$
 */
 
@@ -44,6 +44,7 @@ int glasstile_init(magic_api * api);
 int glasstile_get_tool_count(magic_api * api);
 SDL_Surface *glasstile_get_icon(magic_api * api, int which);
 char *glasstile_get_name(magic_api * api, int which);
+int glasstile_get_group(magic_api * api, int which);
 char *glasstile_get_description(magic_api * api, int which, int mode);
 static void do_glasstile(void *ptr, int which, SDL_Surface * canvas, SDL_Surface * last, int x, int y);
 void glasstile_drag(magic_api * api, int which, SDL_Surface * canvas,
@@ -104,6 +105,12 @@ char *glasstile_get_name(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_U
   return (strdup(gettext_noop("Glass Tile")));
 }
 
+// Return our groups
+int glasstile_get_group(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
+{
+  return MAGIC_TYPE_DISTORTS;
+}
+
 // Return our descriptions, localized:
 char *glasstile_get_description(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode)
 {
@@ -265,7 +272,7 @@ void glasstile_click(magic_api * api, int which, int mode,
       update_rect->w = canvas->w;
       update_rect->h = canvas->h;
 
-      /* FIXME: Play sfx */
+      api->playsound(glasstile_snd, 128, 255);
     }
 }
 
