@@ -5,7 +5,7 @@
   Tux Paint - A simple drawing program for children.
 
   by Albert Cahalan <albert@users.sf.net>
-  Copyright (c) 2002-2008 by Bill Kendrick and others; see AUTHORS.txt
+  Copyright (c) 2002-2021 by Bill Kendrick and others; see AUTHORS.txt
   bill@newbreedsoftware.com
   http://www.tuxpaint.org/
 
@@ -24,7 +24,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
-  Last updated: July 8, 2008
+  Last updated: September 21, 2021
   $Id$
 */
 
@@ -47,6 +47,7 @@ Uint32 grass_api_version(void);
 int grass_get_tool_count(magic_api * api);
 SDL_Surface *grass_get_icon(magic_api * api, int which);
 char *grass_get_name(magic_api * api, int which);
+int grass_get_group(magic_api * api, int which);
 char *grass_get_description(magic_api * api, int which, int mode);
 void grass_drag(magic_api * api, int which, SDL_Surface * canvas,
                 SDL_Surface * last, int ox, int oy, int x, int y, SDL_Rect * update_rect);
@@ -107,6 +108,12 @@ char *grass_get_name(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSE
   return (strdup(gettext_noop("Grass")));
 }
 
+// Return our groups:
+int grass_get_group(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
+{
+  return MAGIC_TYPE_PAINTING;
+}
+
 // Return our descriptions, localized:
 char *grass_get_description(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED)
 {
