@@ -11,7 +11,7 @@
   * Pere Pujal for joining all toghether
   * Caroline Ford for the text descriptions
 
-  Copyright (c) 2002-2009 by Bill Kendrick and others; see AUTHORS.txt
+  Copyright (c) 2002-2021 by Bill Kendrick and others; see AUTHORS.txt
   bill@newbreedsoftware.com
   http://www.tuxpaint.org/
 
@@ -30,7 +30,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
-  Last updated: May 6, 2009
+  Last updated: September 21, 2021
   $Id$
 */
 
@@ -63,6 +63,7 @@ int mosaic_shaped_init(magic_api * api);
 int mosaic_shaped_get_tool_count(magic_api * api);
 SDL_Surface *mosaic_shaped_get_icon(magic_api * api, int which);
 char *mosaic_shaped_get_name(magic_api * api, int which);
+int mosaic_shaped_get_group(magic_api * api, int which);
 
 char *mosaic_shaped_get_description(magic_api * api, int which, int mode);
 
@@ -194,6 +195,12 @@ char *mosaic_shaped_get_name(magic_api * api ATTRIBUTE_UNUSED, int which)
   return (strdup(gettext_noop(mosaic_shaped_names[which])));
 }
 
+// Return our groups (all the same!)
+int mosaic_shaped_get_group(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
+{
+  return MAGIC_TYPE_DISTORTS;
+}
+
 // Return our descriptions, localized:
 char *mosaic_shaped_get_description(magic_api * api ATTRIBUTE_UNUSED, int which, int mode)
 {
