@@ -1,7 +1,7 @@
 /*
   fonts.c
 
-  Copyright (c) 2009-2020
+  Copyright (c) 2009-2021
   http://www.tuxpaint.org/
 
   This program is free software; you can redistribute it and/or modify
@@ -19,7 +19,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
-  $Id$
+  Last modified: 2021.11.08
 */
 
 #include <stdio.h>
@@ -66,6 +66,7 @@
 
 #ifdef WIN32
 #include "win32_print.h"
+extern char *strcasestr(const char *haystack, const char *needle);
 #endif
 
 #if defined(__MACOS__)
@@ -141,7 +142,9 @@ int all_locale_fonts;
 volatile long font_thread_done;
 volatile long font_thread_aborted;
 volatile long waiting_for_fonts;
+#ifdef FORKED_FONTS
 static int font_scanner_pid;
+#endif
 int font_socket_fd;
 
 TuxPaint_Font *medium_font, *small_font, *large_font, *locale_font;
@@ -201,47 +204,28 @@ TuxPaint_Font *load_locale_font(TuxPaint_Font * fallback, int size)
         }
 #endif
 
-/* Not sure why this is like this; we're in a function that's not
-   even defined, unless NO_SDLPANGO is set, so this can't happen
-   -bjk 2017.10.15 */
-/*
-#ifndef NO_SDLPANGO
-      if (!ret)
-        {
-          ret = try_alternate_font(size);
-          if (!ret)
-            {
-              fprintf(stderr,
-                      "\nWarning: Can't load font for this locale:\n"
-                      "%s\n"
-                      "The Simple DirectMedia Layer error that occurred was:\n"
-                      "%s\n\n" "Will use default (American English) instead.\n\n", str, SDL_GetError());
-              button_label_y_nudge = smash_i18n();
-            }
-        }
-#endif
-*/
       return ret ? ret : fallback;
     }
 }
-#endif
+#endif // ifdef NO_SDLPANGO
+
 
 void TuxPaint_Font_CloseFont(TuxPaint_Font * tpf)
 {
 #ifdef DEBUG
-  printf("TuxPaint_Font_CloseFont step 1 (%p)\n", tpf); //EP
+  printf("%s:%d - TuxPaint_Font_CloseFont step 1 (%p)\n", __FILE__, __LINE__, tpf);
 #endif
   if (!tpf)
-    return;                     //EP
+    return;
 
 #ifndef NO_SDLPANGO
 #ifdef DEBUG
-  printf("TuxPaint_Font_CloseFont step 2 (%p, %d)\n", tpf->pango_context, tpf->typ);    //EP
+  printf("%s:%d - TuxPaint_Font_CloseFont step 2 (%p, %d)\n", __FILE__, __LINE__, tpf->pango_context, tpf->typ);
 #endif
   if (tpf->typ == FONT_TYPE_PANGO)
-    if (tpf->pango_context)     //EP
+    if (tpf->pango_context)
       {
-#ifndef __APPLE__               //EP added ifdef because SDLPango_FreeContext sometimes crashed with "pointer being freed was not allocated"
+#ifndef __APPLE__ //EP added ifdef because SDLPango_FreeContext sometimes crashed with "pointer being freed was not allocated"
         SDLPango_FreeContext(tpf->pango_context);
 #endif
         tpf->pango_context = NULL;
@@ -249,11 +233,11 @@ void TuxPaint_Font_CloseFont(TuxPaint_Font * tpf)
 #endif
 
 #ifdef DEBUG
-  printf("TuxPaint_Font_CloseFont step 3 (%p, %d)\n", tpf->ttf_font, tpf->typ); //EP
+  printf("%s:%d - TuxPaint_Font_CloseFont step 3 (%p, %d)\n", __FILE__, __LINE__, tpf->ttf_font, tpf->typ);
   fflush(stdout);
 #endif
   if (tpf->typ == FONT_TYPE_TTF)
-    if (tpf->ttf_font)          //EP
+    if (tpf->ttf_font)
       {
         TTF_CloseFont(tpf->ttf_font);
         tpf->ttf_font = NULL;
@@ -270,7 +254,9 @@ void TuxPaint_Font_CloseFont(TuxPaint_Font * tpf)
 
 TuxPaint_Font *TuxPaint_Font_OpenFont(const char *pangodesc, const char *ttffilename, int size)
 {
+  TTF_Font *ttf_font;
   TuxPaint_Font *tpf = NULL;
+  char * familyname;
   int i;
 
 #ifndef NO_SDLPANGO
@@ -278,11 +264,10 @@ TuxPaint_Font *TuxPaint_Font_OpenFont(const char *pangodesc, const char *ttffile
 #endif
 
 #ifdef DEBUG
-  printf("OpenFont(pango:\"%s\", ttf:\"%s\")\n", pangodesc, ttffilename);
+  printf("%s:%d - OpenFont(pango:\"%s\", ttf:\"%s\")\n", __FILE__, __LINE__, pangodesc, ttffilename);
 #endif
 
 #ifndef NO_SDLPANGO
-
   if (pangodesc != NULL && pangodesc[0] != '\0')
     {
       tpf = (TuxPaint_Font *) malloc(sizeof(TuxPaint_Font));
@@ -291,14 +276,14 @@ TuxPaint_Font *TuxPaint_Font_OpenFont(const char *pangodesc, const char *ttffile
       tpf->desc = strdup(desc);
 
 #ifdef DEBUG
-      printf("Creating context: \"%s\"\n", desc);
+      printf("%s:%d - Creating Pango context: \"%s\"\n", __FILE__, __LINE__, desc);
 #endif
 
       tpf->pango_context = SDLPango_CreateContext_GivenFontDesc(desc);
       if (tpf->pango_context == NULL)
         {
 #ifdef DEBUG
-          printf("Failed to load %s\n", desc);
+          printf("%s:%d - Failed to load %s\n", __FILE__, __LINE__, desc);
 #endif
           free(tpf);
           tpf = NULL;
@@ -307,18 +292,21 @@ TuxPaint_Font *TuxPaint_Font_OpenFont(const char *pangodesc, const char *ttffile
         tpf->height = size;     /* FIXME: Is this accurate!? -bjk 2007.07.12 */
 
 #ifdef DEBUG
-      printf("TuxPaint_Font_OpenFont() done\n");
+      printf("%s:%d - TuxPaint_Font_OpenFont(\"%s\", \"%s\", %d) done (SDL_Pango)\n\n", __FILE__, __LINE__, pangodesc, ttffilename, size);
       fflush(stdout);
 #endif
 
       return (tpf);
     }
-#endif
+#endif // #ifndef NO_SDLPANGO
+
+
+  /* -- Did not, at this point, load the font using SDL_Pango -- */
 
   if (ttffilename != NULL && ttffilename[0] != '\0')
     {
 #ifdef DEBUG
-      printf("Opening TTF\n");
+      printf("%s:%d - Considering loading TTF \"%s\"\n", __FILE__, __LINE__, ttffilename);
       fflush(stdout);
 #endif
 
@@ -326,49 +314,83 @@ TuxPaint_Font *TuxPaint_Font_OpenFont(const char *pangodesc, const char *ttffile
       while (problemFonts[i] != NULL)
         {
           if (!strcmp(ttffilename, problemFonts[i++]))
-            return NULL;        /* bail on known problematic fonts that cause TTF_OpenFont to crash */
+            {
+#ifdef DEBUG
+              fprintf(stderr, "Notice: Skipping problematic font: \"%s\"\n", ttffilename);
+#endif
+              return NULL;        /* bail on known problematic fonts that cause TTF_OpenFont to crash */
+            }
         }
 
       i = 0;
       while (problemFontExtensions[i] != NULL)
         {
           if (strstr(ttffilename, problemFontExtensions[i++]))
-            return NULL;        /* bail on known problematic font types that cause TTF_OpenFont to crash */
+            {
+#ifdef DEBUG
+              fprintf(stderr, "Notice: Skipping font with problematic extension: \"%s\"\n", ttffilename);
+#endif
+              return NULL;        /* bail on known problematic font types that cause TTF_OpenFont to crash */
+            }
         }
 
-      tpf = (TuxPaint_Font *) malloc(sizeof(TuxPaint_Font));
-      tpf->typ = FONT_TYPE_TTF;
-      tpf->ttf_font = TTF_OpenFont(ttffilename, size);
-      tpf->desc = strdup(ttffilename);
+      ttf_font = TTF_OpenFont(ttffilename, size);
+
+      if (ttf_font == NULL) {
+        fprintf(stderr, "Cannot open TTF font '%s' (size %d)\n", ttffilename, size);
+        return NULL;
+      }
+
+      familyname = TTF_FontFaceFamilyName(ttf_font); /* N.B.: I don't believe we're supposed to free() this... -bjk 2021.10.26 */
+      (void) familyname; // avoid compiler complaints if NO_SDLPANGO is set, or ALWAYS_LOAD_FONT_WITH_PANGO is not set, and DEBUG is not set
 
 #ifdef DEBUG
-      printf("Loaded %s: %d->%d\n", ttffilename, tpf, tpf->ttf_font);
+      printf("%s:%d - Loaded %s (\"%s\")\n", __FILE__, __LINE__, ttffilename, (familyname != NULL ? familyname : "<NULL>"));
       fflush(stdout);
 #endif
 
-      if (tpf->ttf_font == NULL)
-        {
+
+/* This is currently disabled, as it is under construction (and may be moot under SDL2) -bjk 2021.10.28 */
+#ifdef ALWAYS_LOAD_FONT_WITH_PANGO
+#ifndef NO_SDLPANGO
+      /* -- Try loading the font with Pango, instead! */
+      tpf = TuxPaint_Font_OpenFont(familyname, "", size);
+      if (tpf != NULL) {
+        /* Success! Clean up and return the TuxPaint_Font that we got back */
 #ifdef DEBUG
-          printf("Failed to load %s: %s\n", ttffilename, SDL_GetError());
+        printf("%s:%d - Loaded via SDL_Pango!\n", __FILE__, __LINE__);
+        printf("%s:%d - TuxPaint_Font_OpenFont(\"%s\", \"%s\", %d) done (SDL_ttf -> SDL_Pango)\n\n", __FILE__, __LINE__, pangodesc, ttffilename, size);
+        fflush(stdout);
 #endif
-          free(tpf);
-          tpf = NULL;
-        }
-      else
-        {
+        TTF_CloseFont(ttf_font);
+        return(tpf);
+      }
+#endif // #ifndef NO_SDLPANGO
+#endif
+
+
+      /* -- Proceed with loading the TTF font file using SDL_ttf */
+
+      tpf = (TuxPaint_Font *) malloc(sizeof(TuxPaint_Font));
+      tpf->typ = FONT_TYPE_TTF;
+      tpf->ttf_font = ttf_font;
+      tpf->desc = strdup(ttffilename);
+
 #ifdef DEBUG
-          printf("Succeeded loading %s\n", ttffilename);
+      printf("%s:%d - Succeeded loading %s via SDL_ttf\n", __FILE__, __LINE__, ttffilename);
 #endif
-          tpf->height = TTF_FontHeight(tpf->ttf_font);
-        }
+      tpf->height = TTF_FontHeight(tpf->ttf_font);
+
+#ifdef DEBUG
+      printf("%s:%d - TuxPaint_Font_OpenFont(\"%s\", \"%s\", %d) done (SDL_ttf)\n\n", __FILE__, __LINE__, pangodesc, ttffilename, size);
+      fflush(stdout);
+#endif
+
+      return (tpf);
     }
 
-#ifdef DEBUG
-  printf("TuxPaint_Font_OpenFont() done\n");
-  fflush(stdout);
-#endif
-
-  return (tpf);
+  fprintf(stderr, "TuxPaint_Font_OpenFont() called with no loadable font\n");
+  return NULL;
 }
 
 
@@ -1013,14 +1035,14 @@ static void loadfonts(SDL_Surface * screen, const char *const dir)
 #endif
 
 #ifdef DEBUG
-  printf("Grouping fonts...\n");
+  printf("%s:%d - Grouping %d fonts...\n", __FILE__, __LINE__, num_font_styles);
   fflush(stdout);
 #endif
 
   groupfonts();
 
 #ifdef DEBUG
-  printf("Finished loading the fonts\n");
+  printf("%s:%d - Finished loading the fonts\n", __FILE__, __LINE__);
   fflush(stdout);
 #endif
 
@@ -1099,7 +1121,7 @@ void run_font_scanner(SDL_Surface * screen, const char *restrict const locale)
   buf = malloc(size);
   walk = buf;
 #ifdef DEBUG
-  printf("Sending %u bytes with %u families.\n", size, num_font_families);
+  printf("%s:%d - Sending %u bytes with %u families.\n", __FILE__, __LINE__, size, num_font_families);
 #endif
   *walk++ = num_font_families & 0xffu;
   *walk++ = num_font_families >> 8u;
@@ -1192,7 +1214,7 @@ void receive_some_font_info(SDL_Surface * screen)
         }
       rc = read(font_socket_fd, buf + buf_fill, buf_size - buf_fill);
 #ifdef DEBUG
-      printf("read: fd=%d buf_fill=%u buf_size=%u rc=%ld\n", font_socket_fd, buf_fill, buf_size, (long int)rc);
+      printf("%s:%d - read: fd=%d buf_fill=%u buf_size=%u rc=%ld\n", __FILE__, __LINE__, font_socket_fd, buf_fill, buf_size, (long int)rc);
 #endif
 
       if (rc == -1)
@@ -1235,7 +1257,7 @@ void receive_some_font_info(SDL_Surface * screen)
   num_font_families = *(unsigned char *)walk++;
   num_font_families += *(unsigned char *)walk++ << 8u;
 #ifdef DEBUG
-  printf("Got %u bytes with %u families.\n", buf_fill, num_font_families);
+  printf("%s:%d - Got %u bytes with %u families.\n", __FILE__, __LINE__, buf_fill, num_font_families);
 #endif
   user_font_families = malloc(num_font_families * sizeof *user_font_families);
 
@@ -1294,14 +1316,14 @@ TuxPaint_Font *getfonthandle(int desire)
   char description[1024];
 
 #ifdef DEBUG
-  printf("\ngetfonthandle(%d)...\n", desire);
+  printf("%s:%d - \ngetfonthandle(%d)...\n", __FILE__, __LINE__, desire);
   fflush(stdout);
 #endif
 
   if (fi == NULL)
     {
 #ifdef DEBUG
-      printf("getfonthandle(%d) points to a NULL family\n", desire);
+      printf("%s:%d - getfonthandle(%d) points to a NULL family\n", __FILE__, __LINE__, desire);
       fflush(stdout);
 #endif
       return NULL;
@@ -1310,21 +1332,21 @@ TuxPaint_Font *getfonthandle(int desire)
   if (fi->filename != NULL)
     {
 #ifdef DEBUG
-      printf("Setting 'name' to fi->filename[%d (0x%x)]\n", (int)text_state, (int)text_state);
+      printf("%s:%d - Setting 'name' to fi->filename[%d (0x%x)]\n", __FILE__, __LINE__, (int)text_state, (int)text_state);
       fflush(stdout);
 #endif
 
       name = fi->filename[text_state];
 
 #ifdef DEBUG
-      printf("Which is: %s\n", name);
+      printf("%s:%d - Which is: %s\n", __FILE__, __LINE__, name);
       fflush(stdout);
 #endif
     }
   else
     {
-#ifdef DEBUG                    //EP fixed typo: replaced DBEUG with DEBUG
-      printf("fi->filename is NULL\n");
+#ifdef DEBUG
+      printf("%s:%d - fi->filename is NULL\n", __FILE__, __LINE__);
       fflush(stdout);
 #endif
 
@@ -1334,7 +1356,7 @@ TuxPaint_Font *getfonthandle(int desire)
   if (fi->handle)
     {
 #ifdef DEBUG
-      printf("fi->handle was set (0x%x)\n", (int)(intptr_t) fi->handle);        //EP added (intptr_t) to avoid warning on x64
+      printf("%s:%d - fi->handle was set (0x%x)\n", __FILE__, __LINE__, (int)(intptr_t) fi->handle);
 
       fflush(stdout);
 #endif
@@ -1342,7 +1364,7 @@ TuxPaint_Font *getfonthandle(int desire)
     }
 
 #ifdef DEBUG
-  printf("fi->handle was not yet set\n");
+  printf("%s:%d - fi->handle was not yet set\n", __FILE__, __LINE__);
   fflush(stdout);
 #endif
 
@@ -1388,7 +1410,7 @@ TuxPaint_Font *getfonthandle(int desire)
     if (!name)
       {
 #ifdef DEBUG
-        printf("name is still NULL\n");
+        printf("%s:%d - name is still NULL\n", __FILE__, __LINE__);
         fflush(stdout);
 #endif
         return (NULL);
@@ -1406,7 +1428,7 @@ TuxPaint_Font *getfonthandle(int desire)
   if (fi->handle == NULL)
     {
 #ifdef DEBUG
-      printf("fi->handle is NULL!\n");
+      printf("%s:%d - fi->handle is NULL!\n", __FILE__, __LINE__);
       fflush(stdout);
 #endif
       return (NULL);
@@ -1417,14 +1439,14 @@ TuxPaint_Font *getfonthandle(int desire)
       if (fi->handle->ttf_font == NULL)
         {
 #ifdef DEBUG
-          printf("fi->handle->ttf_font is NULL!\n");
+          printf("%s:%d - fi->handle->ttf_font is NULL!\n", __FILE__, __LINE__);
           fflush(stdout);
 #endif
           return (NULL);
         }
 
 #ifdef DEBUG
-      printf("calling TTF_SetFontStyle(0x%x)\n", missing);
+      printf("%s:%d - calling TTF_SetFontStyle(0x%x)\n", __FILE__, __LINE__, missing);
       fflush(stdout);
 #endif
 
@@ -1433,7 +1455,7 @@ TuxPaint_Font *getfonthandle(int desire)
 
 #ifndef NO_SDLPANGO
   if (fi->handle->typ == FONT_TYPE_PANGO)
-    printf("It's a Pango context...\n");
+    printf("%s:%d - It's a Pango context...\n", __FILE__, __LINE__);
 #endif
 
   return fi->handle;
@@ -1576,7 +1598,7 @@ int TuxPaint_Font_FontHeight(TuxPaint_Font * tpf)
   if (tpf == NULL)
     {
 #ifdef DEBUG
-      printf("TuxPaint_Font_FontHeight() received NULL\n");
+      printf("%s:%d - TuxPaint_Font_FontHeight() received NULL\n", __FILE__, __LINE__);
       fflush(stdout);
 #endif
       return (1);
@@ -1590,7 +1612,7 @@ const char *TuxPaint_Font_FontFaceFamilyName(TuxPaint_Font * tpf)
   if (tpf == NULL)
     {
 #ifdef DEBUG
-      printf("TuxPaint_Font_FontFaceFamilyName() received NULL\n");
+      printf("%s:%d - TuxPaint_Font_FontFaceFamilyName() received NULL\n", __FILE__, __LINE__);
       fflush(stdout);
 #endif
       return ("");
@@ -1610,7 +1632,7 @@ const char *TuxPaint_Font_FontFaceFamilyName(TuxPaint_Font * tpf)
     return (TTF_FontFaceFamilyName(tpf->ttf_font));
 
 #ifdef DEBUG
-  printf("TuxPaint_Font_FontFaceFamilyName() is confused\n");
+  printf("%s:%d - TuxPaint_Font_FontFaceFamilyName() is confused\n", __FILE__, __LINE__);
 #endif
 
   return ("");
@@ -1621,7 +1643,7 @@ const char *TuxPaint_Font_FontFaceStyleName(TuxPaint_Font * tpf)
   if (tpf == NULL)
     {
 #ifdef DEBUG
-      printf("TuxPaint_Font_FontFaceStyleName() received NULL\n");
+      printf("%s:%d - TuxPaint_Font_FontFaceStyleName() received NULL\n", __FILE__, __LINE__);
       fflush(stdout);
 #endif
       return ("");
@@ -1641,7 +1663,7 @@ const char *TuxPaint_Font_FontFaceStyleName(TuxPaint_Font * tpf)
     return (TTF_FontFaceStyleName(tpf->ttf_font));
 
 #ifdef DEBUG
-  printf("TuxPaint_Font_FontFaceStyleName() is confused\n");
+  printf("%s:%d - TuxPaint_Font_FontFaceStyleName() is confused\n", __FILE__, __LINE__);
 #endif
 
   return ("");
