@@ -4,7 +4,7 @@
   For Tux Paint
   Language-related functions
 
-  Copyright (c) 2002-2012 by Bill Kendrick and others
+  Copyright (c) 2002-2020 by Bill Kendrick and others
   bill@newbreedsoftware.com
   http://www.tuxpaint.org/
 
@@ -25,7 +25,7 @@
 
   $Id$
   
-  June 14, 2002 - December 11, 2016
+  June 14, 2002 - July 26, 2020
 */
 
 
@@ -101,7 +101,7 @@ enum
   LANG_KN,                      /* Kannada */
   LANG_KM,                      /* Khmer */
   LANG_KOK_ROMAN,               /* Konkani (Roman) */
-  LANG_KOK,                     /* Konkani (Devaganari) */
+  LANG_KOK,                     /* Konkani (Devanagari) */
   LANG_KO,                      /* Korean */
   LANG_KS_DEVANAGARI,           /* Kashmiri (Devanagari script) */
   LANG_KS,                      /* Kashmiri (Perso-Arabic script) */
@@ -137,6 +137,7 @@ enum
   LANG_SAT_OL_CHIKI,
   LANG_SAT,                     /* Santali */
   LANG_SA,                      /* Sanskrit */
+  LANG_SC,                      /* Sardinian */
   LANG_SD,                      /* Sindhi (Perso-Arabic) */
   LANG_SD_DEVANAGARI,           /* Sindhi (Devanagari) */
   LANG_SHS,                     /* Shuswap */
@@ -188,7 +189,6 @@ extern int need_own_font;
 extern int need_right_to_left;  // Right-justify
 extern int need_right_to_left_word;     // Words need to be reversed, too! (e.g., Hebrew, but not Arabic)
 extern const char *lang_prefix, *short_lang_prefix;
-extern int num_wished_langs;
 
 typedef struct w_langs
 {
@@ -206,7 +206,7 @@ extern w_langs wished_langs[255];
 /* Function prototypes: */
 
 int get_current_language(void);
-int setup_i18n(const char *restrict lang, const char *restrict locale) MUST_CHECK;
+int setup_i18n(const char *restrict lang, const char *restrict locale, int * ptr_num_wished_languages) MUST_CHECK;
 
 #ifdef NO_SDLPANGO
      int smash_i18n(void) MUST_CHECK;
