@@ -43,6 +43,12 @@
 #include <wchar.h>
 
 #include "im.h"
+#include "i18n.h"
+#include "debug.h"
+
+#ifdef DEBUG
+#include <assert.h>
+#endif
 
 
 /* ***************************************************************************
@@ -94,7 +100,9 @@ static const char *const im_tip_text[NUM_IM_TIPS] = {
 * CONSTANTS
 */
 
-/* #define IM_DEBUG       1 */
+#ifdef DEBUG
+#define IM_DEBUG         1
+#endif
 
 #define MAX_SECTIONS     8      /* Maximum numbers of sections in *.im file */
 #define MAX_UNICODE_SEQ 16      /* Output of state machine, including NUL */
@@ -610,10 +618,10 @@ static int charmap_load(CHARMAP * cm, const char *path)
         default:
           if (charmap_add(cm, section, buf, unicode, flag))
             {
-              size_t i = 0;
-
 #ifndef __BEOS__
 #if defined __GLIBC__ && __GLIBC__ == 2 && __GLIBC_MINOR__ >=2 || __GLIBC__ > 2 || __APPLE__
+              size_t i = 0;
+
               fwprintf(stderr, L"Unable to add sequence '%ls', unicode ", buf);
               for (i = 0; i < wcslen(unicode); i++)
                 fwprintf(stderr, L"%04X ", (int)unicode[i]);
@@ -1397,7 +1405,6 @@ static int im_event_ja(IM_DATA * im, SDL_keysym ks)
     case SDLK_RSHIFT:
     case SDLK_LCTRL:
     case SDLK_RCTRL:
-    case SDLK_LALT:
     case SDLK_LMETA:
     case SDLK_RMETA:
     case SDLK_LSUPER:
@@ -1406,8 +1413,9 @@ static int im_event_ja(IM_DATA * im, SDL_keysym ks)
     case SDLK_COMPOSE:
       break;
 
-      /* Right-Alt mapped to mode-switch */
+      /* Left-Alt & Right-Alt mapped to mode-switch */
     case SDLK_RALT:
+    case SDLK_LALT:
       cm.section = ((cm.section + 1) % SEC_TOTAL);      /* Change section */
       im_softreset(im);         /* Soft reset */
 
@@ -1652,7 +1660,7 @@ static int im_event_ko(IM_DATA * im, SDL_keysym ks)
     case SDLK_COMPOSE:
       break;
 
-      /* Right-Alt mapped to mode-switch */
+      /* Left-Alt & Right-Alt mapped to mode-switch */
     case SDLK_LALT:
     case SDLK_RALT:
       cm.section = ((cm.section + 1) % SEC_TOTAL);      /* Change section */
@@ -1876,8 +1884,7 @@ void im_init(IM_DATA * im, int lang)
 
 #ifdef DEBUG
   assert(0 <= im->lang && im->lang < NUM_LANGS);
-  if (im_event_fp)
-    printf("Initializing IM for %s...\n", lang_prefixes[im->lang]);
+  printf("Initializing IM for %s...\n", lang_prefixes[im->lang]);
 #endif
 
   /* Initialize the individual IM */
