@@ -19,11 +19,11 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
-  Copyright (c) 2002-2020 by Bill Kendrick
+  Copyright (c) 2002-2021 by Bill Kendrick
   bill@newbreedsoftware.com
   http://www.tuxpaint.org/
 
-  June 14, 2002 - August 15, 2020
+  June 14, 2002 - October 25, 2021
   $Id$
 */
 
@@ -120,9 +120,8 @@ const char *const tool_tips[NUM_TOOLS] = {
   // Line tool instructions
   gettext_noop("Click to start drawing a line. Let go to complete it."),
 
-  // Shape tool instructions
-  gettext_noop
-    ("Pick a shape. Click to start drawing, drag, and let go when it is the size you want. Move around to rotate it, and click to draw it."),
+  // Shape tool instructions (defined in "shapes.h")
+  "",
 
   // Text tool instructions
   gettext_noop
@@ -132,8 +131,8 @@ const char *const tool_tips[NUM_TOOLS] = {
   gettext_noop
     ("Choose a style of text. Click on your drawing and you can start typing. Press [Enter] or [Tab] to complete the text. By using the selector button and clicking an existing label, you can move it, edit it and change its text style."),
 
-  // Fill tool instructions
-  gettext_noop("Click in the picture to fill that area with color."),
+  // Fill tool instructions (defined in "fill_tools.h")
+  "",
 
   // Magic tool instruction
   gettext_noop("Pick a magical effect to use on your drawing!"),
@@ -165,12 +164,14 @@ const char *const tool_tips[NUM_TOOLS] = {
 
 // Instruction while using Line tool (after click, before release)
 #define TIP_LINE_START gettext_noop("Let go of the button to complete the line.")
+#define TIP_LINE_MOVING gettext_noop("Let go of the button to complete the line. (Your line's angle is %.0f degrees.)")
 
 // Instruction while using Shape tool (after first click, before release)
 #define TIP_SHAPE_START gettext_noop("Hold the button to stretch the shape.")
 
 // Instruction while finishing Shape tool (after release, during rotation step before second click)
 #define TIP_SHAPE_NEXT gettext_noop("Move the mouse to rotate the shape. Click to draw it.")
+#define TIP_SHAPE_ROTATING gettext_noop("Move the mouse to rotate the shape. Click to draw it. (It is rotated %d degrees.)")
 
 // Notification that 'New' action was aborted (current image would have been lost)
 #define TIP_NEW_ABORT gettext_noop("OK then… Let’s keep drawing this one!")
